==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/wavpack/translations/wavpack_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="28"/>
        <source>WavPack Plugin</source>
        <translation>WavPack 插件</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPackk Files</source>
        <translation type="obsolete">WavPackk 檔案</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="89"/>
        <source>About WavPack Audio Plugin</source>
        <translation>關於 WavPack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="90"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="92"/>
        <source>WavPack library version:</source>
        <translation>WavPack 程式庫版本：</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="93"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPack Files</source>
        <translation>WavPack 檔案</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>詳細資料</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>檔案路徑：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>WavPack 資訊</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>取樣率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>音頻通道：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>封包比：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE 標簽</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>音軌：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>年代：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>流派：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>備註：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/wavpack/translations/wavpack_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>WavPack 插件</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="129"/>
        <source>About WavPack Audio Plugin</source>
        <translation>關於 WavPack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="130"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="131"/>
        <source>WavPack library version:</source>
        <translation>WavPack 程式庫版本：</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>WavPack 檔案</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>詳細資料</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>檔案路徑：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>WavPack 資訊</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="58"/>
        <location filename="../detailsdialog.ui" line="75"/>
        <location filename="../detailsdialog.ui" line="92"/>
        <location filename="../detailsdialog.ui" line="118"/>
        <location filename="../detailsdialog.ui" line="135"/>
        <location filename="../detailsdialog.ui" line="152"/>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>取樣率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>音頻通道：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>封包比：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE 標簽</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>音軌：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>年代：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>流派：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>備註：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>
